==> libgtk-java-2.3.4.tar.gz: libgtk-java-2.3.4/gtk/src/java/org/gnu/gtk/FileChooserDialog.java <==
/*
 * Java-Gnome Bindings Library
 * 
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 * 
 * The Java-Gnome bindings library is free software distributed under the terms
 * of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

/**
 * 
 */
public class FileChooserDialog extends Dialog implements FileChooser {

	public FileChooserDialog(String title, Window parent, FileChooserAction action) {
		int hndl = 0;
		if (null != parent)
			hndl = parent.getHandle();
		handle = gtk_file_chooser_dialog_new(title, hndl, action.getValue());
		initializeEventHandlers();
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setAction(org.gnu.gtk.FileChooserAction)
	 */
	public void setAction(FileChooserAction action) {
		FileChooserHelper.gtk_file_chooser_set_action(handle, action.getValue());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getAction()
	 */
	public FileChooserAction getAction() {
		return FileChooserAction.intern(FileChooserHelper.gtk_file_chooser_get_action(handle));
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setFolderMode(boolean)
	 */
	public void setFolderMode(boolean folderMode) {
		FileChooserHelper.gtk_file_chooser_set_folder_mode(handle, folderMode);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getFolderMode()
	 */
	public boolean getFolderMode() {
		return FileChooserHelper.gtk_file_chooser_get_folder_mode(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setLocalOnly(boolean)
	 */
	public void setLocalOnly(boolean localOnly) {
		FileChooserHelper.gtk_file_chooser_set_local_only(handle, localOnly);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getLocalOnly()
	 */
	public boolean getLocalOnly() {
		return FileChooserHelper.gtk_file_chooser_get_local_only(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setSelectMultiple(boolean)
	 */
	public void setSelectMultiple(boolean selectMultiple) {
		FileChooserHelper.gtk_file_chooser_set_select_multiple(handle, selectMultiple);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getSelectMultiple()
	 */
	public boolean getSelectMultiple() {
		return FileChooserHelper.gtk_file_chooser_get_select_multiple(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setCurrentName(java.lang.String)
	 */
	public void setCurrentName(String name) {
		FileChooserHelper.gtk_file_chooser_set_current_name(handle, name);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getFilename()
	 */
	public String getFilename() {
		return FileChooserHelper.gtk_file_chooser_get_filename(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setFilename(java.lang.String)
	 */
	public void setFilename(String filename) {
		FileChooserHelper.gtk_file_chooser_set_filename(handle, filename);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#selectFilename(java.lang.String)
	 */
	public void selectFilename(String filename) {
		FileChooserHelper.gtk_file_chooser_select_filename(handle, filename);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#unselectFilename(java.lang.String)
	 */
	public void unselectFilename(String filename) {
		FileChooserHelper.gtk_file_chooser_unselect_filename(handle, filename);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#selectAll()
	 */
	public void selectAll() {
		FileChooserHelper.gtk_file_chooser_select_all(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#unselectAll()
	 */
	public void unselectAll() {
		FileChooserHelper.gtk_file_chooser_unselect_all(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getFilenames()
	 */
	public String[] getFilenames() {
		return FileChooserHelper.gtk_file_chooser_get_filenames(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setCurrentFolder(java.lang.String)
	 */
	public void setCurrentFolder(String folder) {
		FileChooserHelper.gtk_file_chooser_set_current_folder(handle, folder);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getCurrentFolder()
	 */
	public String getCurrentFolder() {
		return FileChooserHelper.gtk_file_chooser_get_current_folder(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getURI()
	 */
	public String getURI() {
		return FileChooserHelper.gtk_file_chooser_get_uri(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setURI(java.lang.String)
	 */
	public void setURI(String uri) {
		FileChooserHelper.gtk_file_chooser_set_uri(handle, uri);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#selectURI(java.lang.String)
	 */
	public void selectURI(String uri) {
		FileChooserHelper.gtk_file_chooser_select_uri(handle, uri);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#unselectURI(java.lang.String)
	 */
	public void unselectURI(String uri) {
		FileChooserHelper.gtk_file_chooser_unselect_uri(handle, uri);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getURIs()
	 */
	public String[] getURIs() {
		return FileChooserHelper.gtk_file_chooser_get_uris(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setCurrentFolderURI(java.lang.String)
	 */
	public void setCurrentFolderURI(String folder) {
		FileChooserHelper.gtk_file_chooser_set_current_folder_uri(handle, folder);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getCurrentFolderURI()
	 */
	public String getCurrentFolderURI() {
		return FileChooserHelper.gtk_file_chooser_get_current_folder_uri(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setPreviewWidget(org.gnu.gtk.Widget)
	 */
	public void setPreviewWidget(Widget previewWidget) {
		FileChooserHelper.gtk_file_chooser_set_preview_widget(handle, previewWidget.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getPreviewWidget()
	 */
	public Widget getPreviewWidget() {
		return new Widget(FileChooserHelper.gtk_file_chooser_get_preview_widget(handle));
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setPreviewWidgetActive(boolean)
	 */
	public void setPreviewWidgetActive(boolean active) {
		FileChooserHelper.gtk_file_chooser_set_preview_widget_active(handle, active);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getPreviewWidgetActive()
	 */
	public boolean getPreviewWidgetActive() {
		return FileChooserHelper.gtk_file_chooser_get_preview_widget_active(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getPreviewFilename()
	 */
	public String getPreviewFilename() {
		return FileChooserHelper.gtk_file_chooser_get_preview_filename(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getPreviewURI()
	 */
	public String getPreviewURI() {
		return FileChooserHelper.gtk_file_chooser_get_preview_uri(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setExtraWidget(org.gnu.gtk.Widget)
	 */
	public void setExtraWidget(Widget extraWidget) {
		FileChooserHelper.gtk_file_chooser_set_extra_widget(handle, extraWidget.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getExtraWidget()
	 */
	public Widget getExtraWidget() {
		return new Widget(FileChooserHelper.gtk_file_chooser_get_extra_widget(handle));
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#addFilter(org.gnu.gtk.FileFilter)
	 */
	public void addFilter(FileFilter filter) {
		FileChooserHelper.gtk_file_chooser_add_filter(handle, filter.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#removeFilter(org.gnu.gtk.FileFilter)
	 */
	public void removeFilter(FileFilter filter) {
		FileChooserHelper.gtk_file_chooser_remove_filter(handle, filter.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#listFilters()
	 */
	public FileFilter[] listFilters() {
		int[] hndls = FileChooserHelper.gtk_file_chooser_list_filters(handle);
		FileFilter[] filters = new FileFilter[hndls.length];
		for (int i = 0; i < hndls.length; i++) {
			filters[i] = new FileFilter(hndls[i]);
		}
		return filters;
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setFilter(org.gnu.gtk.FileFilter)
	 */
	public void setFilter(FileFilter filter) {
		FileChooserHelper.gtk_file_chooser_set_filter(handle, filter.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getFilter()
	 */
	public FileFilter getFilter() {
		return new FileFilter(FileChooserHelper.gtk_file_chooser_get_filter(handle));
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#addShortcutFolder(java.lang.String)
	 */
	public void addShortcutFolder(String folder) throws FileChooserException {
		int err = -1;
		FileChooserHelper.gtk_file_chooser_add_shortcut_folder(handle, folder, new int[] {err});
		if (-1 < err)
			throw new FileChooserException(err);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#removeShortcutFolder(java.lang.String)
	 */
	public void removeShortcutFolder(String folder) throws FileChooserException {
		int err = -1;
		FileChooserHelper.gtk_file_chooser_remove_shortcut_folder(handle, folder, new int[] {err});
		if (-1 < err)
			throw new FileChooserException(err);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#listShortcutFolders()
	 */
	public String[] listShortcutFolders() {
		return FileChooserHelper.gtk_file_chooser_list_shortcut_folders(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#addShortCutURI(java.lang.String)
	 */
	public void addShortcutURI(String uri) throws FileChooserException {
		int err = -1;
		FileChooserHelper.gtk_file_chooser_add_shortcut_folder_uri(handle, uri, new int[] {err});
		if (-1 < err)
			throw new FileChooserException(err);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#removeShortcutURI(java.lang.String)
	 */
	public void removeShortcutURI(String uri) throws FileChooserException {
		int err = -1;
		FileChooserHelper.gtk_file_chooser_remove_shortcut_folder_uri(handle, uri, new int[] {err});
		if (-1 < err)
			throw new FileChooserException(err);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#listShortcutURIs()
	 */
	public String[] listShortcutURIs() {
		return FileChooserHelper.gtk_file_chooser_list_shortcut_folder_uris(handle);
	}

	/****************************************
	 * BEGINNING OF JNI CODE
	 ****************************************/
	native static final protected int gtk_file_chooser_dialog_get_type ();
	native static final protected int gtk_file_chooser_dialog_new(String title, int parent, int action);
	/****************************************
	 * END OF JNI CODE
	 ****************************************/
}

==> libgtk-java-2.3.6.tar.gz: libgtk-java-2.3.6/gtk/src/java/org/gnu/gtk/FileChooserDialog.java <==
/*
 * Java-Gnome Bindings Library
 * 
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 * 
 * The Java-Gnome bindings library is free software distributed under the terms
 * of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

/**
 * 
 */
public class FileChooserDialog extends Dialog implements FileChooser {

	public FileChooserDialog(String title, Window parent, FileChooserAction action) {
		int hndl = 0;
		if (null != parent)
			hndl = parent.getHandle();
		handle = gtk_file_chooser_dialog_new(title, hndl, action.getValue());
		initializeEventHandlers();
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setAction(org.gnu.gtk.FileChooserAction)
	 */
	public void setAction(FileChooserAction action) {
		FileChooserHelper.gtk_file_chooser_set_action(handle, action.getValue());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getAction()
	 */
	public FileChooserAction getAction() {
		return FileChooserAction.intern(FileChooserHelper.gtk_file_chooser_get_action(handle));
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setLocalOnly(boolean)
	 */
	public void setLocalOnly(boolean localOnly) {
		FileChooserHelper.gtk_file_chooser_set_local_only(handle, localOnly);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getLocalOnly()
	 */
	public boolean getLocalOnly() {
		return FileChooserHelper.gtk_file_chooser_get_local_only(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setSelectMultiple(boolean)
	 */
	public void setSelectMultiple(boolean selectMultiple) {
		FileChooserHelper.gtk_file_chooser_set_select_multiple(handle, selectMultiple);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getSelectMultiple()
	 */
	public boolean getSelectMultiple() {
		return FileChooserHelper.gtk_file_chooser_get_select_multiple(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setCurrentName(java.lang.String)
	 */
	public void setCurrentName(String name) {
		FileChooserHelper.gtk_file_chooser_set_current_name(handle, name);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getFilename()
	 */
	public String getFilename() {
		return FileChooserHelper.gtk_file_chooser_get_filename(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setFilename(java.lang.String)
	 */
	public void setFilename(String filename) {
		FileChooserHelper.gtk_file_chooser_set_filename(handle, filename);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#selectFilename(java.lang.String)
	 */
	public void selectFilename(String filename) {
		FileChooserHelper.gtk_file_chooser_select_filename(handle, filename);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#unselectFilename(java.lang.String)
	 */
	public void unselectFilename(String filename) {
		FileChooserHelper.gtk_file_chooser_unselect_filename(handle, filename);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#selectAll()
	 */
	public void selectAll() {
		FileChooserHelper.gtk_file_chooser_select_all(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#unselectAll()
	 */
	public void unselectAll() {
		FileChooserHelper.gtk_file_chooser_unselect_all(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getFilenames()
	 */
	public String[] getFilenames() {
		return FileChooserHelper.gtk_file_chooser_get_filenames(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setCurrentFolder(java.lang.String)
	 */
	public void setCurrentFolder(String folder) {
		FileChooserHelper.gtk_file_chooser_set_current_folder(handle, folder);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getCurrentFolder()
	 */
	public String getCurrentFolder() {
		return FileChooserHelper.gtk_file_chooser_get_current_folder(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getURI()
	 */
	public String getURI() {
		return FileChooserHelper.gtk_file_chooser_get_uri(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setURI(java.lang.String)
	 */
	public void setURI(String uri) {
		FileChooserHelper.gtk_file_chooser_set_uri(handle, uri);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#selectURI(java.lang.String)
	 */
	public void selectURI(String uri) {
		FileChooserHelper.gtk_file_chooser_select_uri(handle, uri);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#unselectURI(java.lang.String)
	 */
	public void unselectURI(String uri) {
		FileChooserHelper.gtk_file_chooser_unselect_uri(handle, uri);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getURIs()
	 */
	public String[] getURIs() {
		return FileChooserHelper.gtk_file_chooser_get_uris(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setCurrentFolderURI(java.lang.String)
	 */
	public void setCurrentFolderURI(String folder) {
		FileChooserHelper.gtk_file_chooser_set_current_folder_uri(handle, folder);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getCurrentFolderURI()
	 */
	public String getCurrentFolderURI() {
		return FileChooserHelper.gtk_file_chooser_get_current_folder_uri(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setPreviewWidget(org.gnu.gtk.Widget)
	 */
	public void setPreviewWidget(Widget previewWidget) {
		FileChooserHelper.gtk_file_chooser_set_preview_widget(handle, previewWidget.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getPreviewWidget()
	 */
	public Widget getPreviewWidget() {
		return new Widget(FileChooserHelper.gtk_file_chooser_get_preview_widget(handle));
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setUsePreviewLabel()
	 */
	public void setUsePreviewLabel(boolean useLabel) {
		FileChooserHelper.gtk_file_chooser_set_use_preview_label(handle, useLabel);
	}
	
	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getUsePreviewLabel()
	 */
	public boolean getUsePreviewLabel() {
		return FileChooserHelper.gtk_file_chooser_get_use_preview_label(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setPreviewWidgetActive(boolean)
	 */
	public void setPreviewWidgetActive(boolean active) {
		FileChooserHelper.gtk_file_chooser_set_preview_widget_active(handle, active);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getPreviewWidgetActive()
	 */
	public boolean getPreviewWidgetActive() {
		return FileChooserHelper.gtk_file_chooser_get_preview_widget_active(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getPreviewFilename()
	 */
	public String getPreviewFilename() {
		return FileChooserHelper.gtk_file_chooser_get_preview_filename(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getPreviewURI()
	 */
	public String getPreviewURI() {
		return FileChooserHelper.gtk_file_chooser_get_preview_uri(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setExtraWidget(org.gnu.gtk.Widget)
	 */
	public void setExtraWidget(Widget extraWidget) {
		FileChooserHelper.gtk_file_chooser_set_extra_widget(handle, extraWidget.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getExtraWidget()
	 */
	public Widget getExtraWidget() {
		return new Widget(FileChooserHelper.gtk_file_chooser_get_extra_widget(handle));
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#addFilter(org.gnu.gtk.FileFilter)
	 */
	public void addFilter(FileFilter filter) {
		FileChooserHelper.gtk_file_chooser_add_filter(handle, filter.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#removeFilter(org.gnu.gtk.FileFilter)
	 */
	public void removeFilter(FileFilter filter) {
		FileChooserHelper.gtk_file_chooser_remove_filter(handle, filter.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#listFilters()
	 */
	public FileFilter[] listFilters() {
		int[] hndls = FileChooserHelper.gtk_file_chooser_list_filters(handle);
		FileFilter[] filters = new FileFilter[hndls.length];
		for (int i = 0; i < hndls.length; i++) {
			filters[i] = new FileFilter(hndls[i]);
		}
		return filters;
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#setFilter(org.gnu.gtk.FileFilter)
	 */
	public void setFilter(FileFilter filter) {
		FileChooserHelper.gtk_file_chooser_set_filter(handle, filter.getHandle());
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#getFilter()
	 */
	public FileFilter getFilter() {
		return new FileFilter(FileChooserHelper.gtk_file_chooser_get_filter(handle));
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#addShortcutFolder(java.lang.String)
	 */
	public void addShortcutFolder(String folder) throws FileChooserException {
		int err = -1;
		FileChooserHelper.gtk_file_chooser_add_shortcut_folder(handle, folder, new int[] {err});
		if (-1 < err)
			throw new FileChooserException(err);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#removeShortcutFolder(java.lang.String)
	 */
	public void removeShortcutFolder(String folder) throws FileChooserException {
		int err = -1;
		FileChooserHelper.gtk_file_chooser_remove_shortcut_folder(handle, folder, new int[] {err});
		if (-1 < err)
			throw new FileChooserException(err);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#listShortcutFolders()
	 */
	public String[] listShortcutFolders() {
		return FileChooserHelper.gtk_file_chooser_list_shortcut_folders(handle);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#addShortCutURI(java.lang.String)
	 */
	public void addShortcutURI(String uri) throws FileChooserException {
		int err = -1;
		FileChooserHelper.gtk_file_chooser_add_shortcut_folder_uri(handle, uri, new int[] {err});
		if (-1 < err)
			throw new FileChooserException(err);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#removeShortcutURI(java.lang.String)
	 */
	public void removeShortcutURI(String uri) throws FileChooserException {
		int err = -1;
		FileChooserHelper.gtk_file_chooser_remove_shortcut_folder_uri(handle, uri, new int[] {err});
		if (-1 < err)
			throw new FileChooserException(err);
	}

	/* (non-Javadoc)
	 * @see org.gnu.gtk.FileChooser#listShortcutURIs()
	 */
	public String[] listShortcutURIs() {
		return FileChooserHelper.gtk_file_chooser_list_shortcut_folder_uris(handle);
	}

	/****************************************
	 * BEGINNING OF JNI CODE
	 ****************************************/
	native static final protected int gtk_file_chooser_dialog_get_type ();
	native static final protected int gtk_file_chooser_dialog_new(String title, int parent, int action);
	/****************************************
	 * END OF JNI CODE
	 ****************************************/
}
